///
///	@file player.h	@brief A play plugin header file.
///
///	Copyright (c) 2012, 2013 by Johns.  All Rights Reserved.
///
///	Contributor(s): Dennis Bendlin
///
///	License: AGPLv3
///
///	This program is free software: you can redistribute it and/or modify
///	it under the terms of the GNU Affero General Public License as
///	published by the Free Software Foundation, either version 3 of the
///	License.
///
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU Affero General Public License for more details.
///
///	$Id: a3630d6fd97bd119844b02c09e587748a20c2e54 $
//////////////////////////////////////////////////////////////////////////////
#include <mpv/client.h>
#ifdef __cplusplus
extern "C"
{
#endif
    /// C callback feed key press
    extern void FeedKeyPress(const char *, const char *, int, int);

    /// C callback enable dummy device
    extern void EnableDummyDevice(void);
    /// C callback disable dummy device
    extern void DisableDummyDevice(void);

    /// C plugin get osd size and ascpect
    //extern void GetOsdSize(int *, int *, double *);

    /// C plugin open osd
    //extern void OsdOpen(void);
    /// C plugin close osd
    extern void OsdClose(mpv_handle *);
    /// C plugin clear osd
    extern void OsdClear(mpv_handle *);
    /// C plugin draw osd pixmap
    extern void OsdDrawARGB(mpv_handle *, int, int, int, int, int, int, const uint8_t *);

    /// C plugin play audio packet
    extern int PlayAudio(const uint8_t *, int, uint8_t);
    /// C plugin play TS audio packet
    extern int PlayTsAudio(const uint8_t *, int);
    /// C plugin set audio volume
    extern void SetVolumeDevice(int);

    /// C plugin play video packet
    extern int PlayVideo(const uint8_t *, int);
    /// C plugin play TS video packet
    extern void PlayTsVideo(const uint8_t *, int);
    /// C plugin grab an image
    extern uint8_t *GrabImage(int *, int, int, int, int);

    /// C plugin set play mode
    extern int SetPlayMode(int);
    /// C plugin get current system time counter
    extern int64_t GetSTC(void);
    /// C plugin get video stream size and aspect
    extern void GetVideoSize(int *, int *, double *);
    /// C plugin set trick speed
    extern void TrickSpeed(int);
    /// C plugin clears all video and audio data from the device
    extern void Clear(void);
    /// C plugin sets the device into play mode
    extern void Play(void);
    /// C plugin sets the device into "freeze frame" mode
    extern void Freeze(void);
    /// C plugin mute audio
    extern void Mute(void);
    /// C plugin display I-frame as a still picture.
    extern void StillPicture(const uint8_t *, int);
    /// C plugin poll if ready
    extern int Poll(int);
    /// C plugin flush output buffers
    extern int Flush(int);

    /// C plugin command line help
    extern const char *CommandLineHelp(void);
    /// C plugin process the command line arguments
    extern int ProcessArgs(int, char *const[]);

    /// C plugin exit + cleanup
    extern void PlayExit(void);
    /// C plugin start code
    extern int Start(void);
    /// C plugin stop code
    extern void Stop(void);
    /// C plugin house keeping
    extern void Housekeeping(void);
    /// C plugin main thread hook
    extern void MainThreadHook(void);

    /// Browser root=start directory
    extern const char *ConfigBrowserRoot;
    ///< Disable remote during external play
    extern char ConfigDisableRemote;
    extern const char *X11DisplayName;	///< x11 display name
    extern int64_t PlayerDvdNav;		///< dvdnav active
    extern char PlayerPaused;		///< player paused
    extern char PlayerSpeed;		///< player playback speed
    extern int PlayerCurrent;		///< current postion in seconds
    extern int PlayerTotal;		///< total length in seconds
    extern char PlayerTitle[256];	///< title from meta data
    extern char *PlayerFilename;	///< filename
    extern int PlayerFps;		///< current frames per second
    extern int PlayerNumChapters;
    extern int PlayerChapter;
    extern unsigned int PlayerChapters[100];
    extern char TitleOverride[256];
    
    static void SendCommand(mpv_handle *ctx, char *cmd, ...);

    /// Start external player
    extern mpv_handle *PlayerStart(const char *name);
    /// Stop external player
    extern void PlayerStop();
    /// Is external player still running
    extern int PlayerIsRunning();

    /// Set player volume
    extern void PlayerSetVolume(mpv_handle *, int);

    /// Player send quit command
    extern void PlayerSendQuit(mpv_handle *);
    /// Player send toggle pause command
    extern void PlayerSendPause(mpv_handle *);
    /// Player send set play speed
    extern void PlayerSendSetSpeed(mpv_handle *, int);
    /// Player send seek
    extern void PlayerSendSeek(mpv_handle *, int);
    /// Player send switch audio track
    extern void PlayerSendSwitchAudio(mpv_handle *);
    /// Player send select subtitle
    extern void PlayerSendSubSelect(mpv_handle *);
    /// Player send dvd-nav up
    extern void PlayerSendDvdNavUp(mpv_handle *);
    /// Player send dvd-nav down
    extern void PlayerSendDiscNavDown(mpv_handle *);
    /// Player send dvd-nav left
    extern void PlayerSendDvdNavLeft(mpv_handle *);
    /// Player send dvd-nav right
    extern void PlayerSendDvdNavRight(mpv_handle *);
    /// Player send dvd-nav menu select
    extern void PlayerSendDiscNavSelect(mpv_handle *);
    /// Player send dvd-nav menu prev
    extern void PlayerSendDvdNavPrev(mpv_handle *);
    /// Player send dvd-nav prev
    extern void PlayerSendDvdNavMenu(mpv_handle *);
    /// Player Next Chapter
    extern void PlayerNextChapter(mpv_handle *);
    /// Player Previous Chapter
    extern void PlayerPreviousChapter(mpv_handle *);

#ifdef __cplusplus
}
#endif
